@@ -12,8 +12,7 @@
 
 #include <vector>
 
-namespace Avogadro {
-namespace Core {
+namespace Avogadro::Core {
 class Atom;
 class Molecule;
 
@@ -39,7 +38,6 @@ private:
   ~AtomUtilities(); // Not implemented
 };
 
-} // namespace Core
-} // namespace Avogadro
+} // namespace Avogadro::Core
 
 #endif // AVOGADRO_QTGUI_ATOMUTILITIES_H
