@@ -22,16 +22,23 @@ struct WrapAtomsToCellFunctor
 
   void operator()(Vector3& pos) { unitCell.wrapCartesian(pos, pos); }
 };
-}
+} // namespace
 
 bool CrystalTools::wrapAtomsToUnitCell(Molecule& molecule)
 {
   if (!molecule.unitCell())
     return false;
 
+  // remove any bonds first - otherwise they may wrap
+  // across the unit cell strangely
+  molecule.clearBonds();
+
   std::for_each(molecule.atomPositions3d().begin(),
                 molecule.atomPositions3d().end(),
                 WrapAtomsToCellFunctor(molecule));
+
+  molecule.perceiveBondsSimple();
+  molecule.perceiveBondOrders();
   return true;
 }
 
@@ -182,7 +189,7 @@ T niggliRound(T v, T dec)
   const T shifted = v * shift;
   return std::floor(shifted + 0.5) / shift;
 }
-}
+} // namespace
 
 bool CrystalTools::niggliReduce(Molecule& molecule, Options opts)
 {
@@ -256,6 +263,9 @@ bool CrystalTools::niggliReduce(Molecule& molecule, Options opts)
 */
 #define NIGGLI_DEBUG(step)
 
+  // Allow Argument Dependent Lookup for swap
+  using std::swap;
+
   // Perform iterative reduction:
   unsigned int iter;
   for (iter = 0; iter < maxIterations; ++iter) {
@@ -264,8 +274,8 @@ bool CrystalTools::niggliReduce(Molecule& molecule, Options opts)
         (fuzzyEqual(A, B, tol) &&
          fuzzyGreaterThan(std::fabs(xi), std::fabs(eta), tol))) {
       cob *= C1;
-      std::swap(A, B);
-      std::swap(xi, eta);
+      swap(A, B);
+      swap(xi, eta);
       NIGGLI_DEBUG(1);
     }
 
@@ -274,8 +284,8 @@ bool CrystalTools::niggliReduce(Molecule& molecule, Options opts)
         (fuzzyEqual(B, C, tol) &&
          fuzzyGreaterThan(std::fabs(eta), std::fabs(zeta), tol))) {
       cob *= C2;
-      std::swap(B, C);
-      std::swap(eta, zeta);
+      swap(B, C);
+      swap(eta, zeta);
       NIGGLI_DEBUG(2);
       continue;
     }
@@ -430,7 +440,7 @@ bool CrystalTools::niggliReduce(Molecule& molecule, Options opts)
 
     // fix coordinates with COB matrix:
     const Matrix3 invCob(cob.inverse());
-    for (auto & fcoord : fcoords) {
+    for (auto& fcoord : fcoords) {
       fcoord = invCob * fcoord;
     }
 
@@ -555,6 +565,10 @@ bool CrystalTools::buildSupercell(Molecule& molecule, unsigned int a,
   Vector3 newB = oldB * b;
   Vector3 newC = oldC * c;
 
+  // archive the old bond pairs and orders
+  Array<std::pair<Index, Index>> bondPairs = molecule.bondPairs();
+  Array<unsigned char> bondOrders = molecule.bondOrders();
+
   // Add in the atoms to the new subcells of the supercell
   Index numAtoms = molecule.atomCount();
   Array<Vector3> atoms = molecule.atomPositions3d();
@@ -575,6 +589,17 @@ bool CrystalTools::buildSupercell(Molecule& molecule, unsigned int a,
     }
   }
 
+  // now we need to add the bonds
+  unsigned copies = molecule.atomCount() / numAtoms;
+  // we loop through the original bonds to add copies
+  for (Index i = 0; i < bondPairs.size(); ++i) {
+    std::pair<Index, Index> bond = bondPairs.at(i);
+    for (unsigned j = 0; j < copies; ++j) {
+      molecule.addBond(bond.first + j * numAtoms, bond.second + j * numAtoms,
+                       bondOrders.at(i));
+    }
+  }
+
   // Now set the unit cell
   molecule.unitCell()->setAVector(newA);
   molecule.unitCell()->setBVector(newB);
@@ -592,7 +617,7 @@ struct TransformAtomsFunctor
 
   void operator()(Vector3& pos) { pos = transform * pos; }
 };
-}
+} // namespace
 
 bool CrystalTools::setCellMatrix(Molecule& molecule,
                                  const Matrix3& newCellColMatrix, Options opt)
@@ -622,7 +647,7 @@ struct FractionalCoordinatesFunctor
 
   void operator()(Vector3& pos) { unitCell.toFractional(pos, pos); }
 };
-}
+} // namespace
 
 bool CrystalTools::fractionalCoordinates(const UnitCell& unitCell,
                                          const Array<Vector3>& cart,
@@ -661,7 +686,7 @@ struct SetFractionalCoordinatesFunctor
 
   Vector3 operator()(const Vector3& pos) { return unitCell.toCartesian(pos); }
 };
-}
+} // namespace
 
 bool CrystalTools::setFractionalCoordinates(Molecule& molecule,
                                             const Array<Vector3>& coords)
@@ -681,4 +706,4 @@ bool CrystalTools::setFractionalCoordinates(Molecule& molecule,
   return true;
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::Core
