@@ -1,25 +1,13 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "mutex.h"
 
 #include <mutex>
 
-namespace Avogadro {
-namespace Core {
+namespace Avogadro::Core {
 
 using std::mutex;
 
@@ -55,4 +43,3 @@ void Mutex::unlock()
   d->lock.unlock();
 }
 }
-}
