@@ -5,7 +5,6 @@
 
 #include "nameatomtyper.h"
 
-#include "atom.h"
 #include "elements.h"
 
 namespace Avogadro::Core {
@@ -14,10 +13,6 @@ NameAtomTyper::NameAtomTyper(const Molecule* mol) : AtomTyper<std::string>(mol)
 {
 }
 
-NameAtomTyper::~NameAtomTyper()
-{
-}
-
 std::string NameAtomTyper::type(const Atom& atom)
 {
   return std::string(Elements::name(atom.atomicNumber()));
