@@ -12,19 +12,19 @@
 namespace Avogadro {
 
 /** Typedefs for vector types. */
-typedef Eigen::Matrix<Real, 2, 1> Vector2;
-typedef Eigen::Matrix<Real, 3, 1> Vector3;
-typedef Eigen::Matrix<Real, 4, 1> Vector4;
+using Vector2 = Eigen::Matrix<Real, 2, 1>;
+using Vector3 = Eigen::Matrix<Real, 3, 1>;
+using Vector4 = Eigen::Matrix<Real, 4, 1>;
 
-typedef Eigen::Matrix<float, 2, 1> Vector2f;
-typedef Eigen::Matrix<float, 3, 1> Vector3f;
-typedef Eigen::Matrix<float, 4, 1> Vector4f;
-typedef Eigen::Matrix<int, 2, 1> Vector2i;
-typedef Eigen::Matrix<int, 3, 1> Vector3i;
-typedef Eigen::Matrix<int, 4, 1> Vector4i;
-typedef Eigen::Matrix<unsigned char, 2, 1> Vector2ub;
-typedef Eigen::Matrix<unsigned char, 3, 1> Vector3ub;
-typedef Eigen::Matrix<unsigned char, 4, 1> Vector4ub;
+using Vector2f = Eigen::Matrix<float, 2, 1>;
+using Vector3f = Eigen::Matrix<float, 3, 1>;
+using Vector4f = Eigen::Matrix<float, 4, 1>;
+using Vector2i = Eigen::Matrix<int, 2, 1>;
+using Vector3i = Eigen::Matrix<int, 3, 1>;
+using Vector4i = Eigen::Matrix<int, 4, 1>;
+using Vector2ub = Eigen::Matrix<unsigned char, 2, 1>;
+using Vector3ub = Eigen::Matrix<unsigned char, 3, 1>;
+using Vector4ub = Eigen::Matrix<unsigned char, 4, 1>;
 
 /** A simple struct composed of Vector3f to represent a frustrum. */
 struct Frustrum
