@@ -41,10 +41,6 @@ using Core::Molecule;
 using Core::Residue;
 using Core::Variant;
 
-CjsonFormat::CjsonFormat() = default;
-
-CjsonFormat::~CjsonFormat() = default;
-
 bool setJsonKey(json& j, Molecule& m, const std::string& key)
 {
   if (j.count(key) && j.find(key)->is_string()) {
@@ -159,7 +155,16 @@ bool CjsonFormat::deserialize(std::istream& file, Molecule& molecule,
     }
   }
 
-  // todo? 2d position
+  // Array of vector3 for forces if available
+  json forces = atoms["forces"];
+  if (isNumericArray(forces) && forces.size() == 3 * atomCount) {
+    for (Index i = 0; i < atomCount; ++i) {
+      auto a = molecule.atom(i);
+      a.setForceVector(
+        Vector3(forces[3 * i], forces[3 * i + 1], forces[3 * i + 2]));
+    }
+  }
+
   // labels
   json labels = atoms["labels"];
   if (labels.is_array() && labels.size() == atomCount) {
@@ -215,7 +220,7 @@ bool CjsonFormat::deserialize(std::istream& file, Molecule& molecule,
     json layerJson = atoms["layer"];
     if (isNumericArray(layerJson)) {
       auto& layer = LayerManager::getMoleculeInfo(&molecule)->layer;
-      for (Index i = 0; i < atomCount; ++i) {
+      for (Index i = 0; i < atomCount && i < layerJson.size(); ++i) {
         while (layerJson[i] > layer.maxLayer()) {
           layer.addLayer();
         }
@@ -242,8 +247,9 @@ bool CjsonFormat::deserialize(std::istream& file, Molecule& molecule,
 
     // are there bond labels?
     json bondLabels = bonds["labels"];
-    if (bondLabels.is_array() && bondLabels.size() == molecule.bondCount()) {
-      for (unsigned int i = 0; i < molecule.bondCount(); ++i) {
+    if (bondLabels.is_array()) {
+      for (unsigned int i = 0;
+           i < molecule.bondCount() && i < bondLabels.size(); ++i) {
         molecule.setBondLabel(i, bondLabels[i]);
       }
     }
@@ -411,6 +417,13 @@ bool CjsonFormat::deserialize(std::istream& file, Molecule& molecule,
           numArray.push_back(static_cast<unsigned int>(number));
         basis->setMolecularOrbitalNumber(numArray);
       }
+      json symmetryLabels = orbitals["symmetries"];
+      if (symmetryLabels.is_array()) {
+        std::vector<std::string> symArray;
+        for (auto& sym : symmetryLabels)
+          symArray.push_back(sym);
+        basis->setSymmetryLabels(symArray);
+      }
       json moCoefficients = orbitals["moCoefficients"];
       json moCoefficientsA = orbitals["alphaCoefficients"];
       json moCoefficientsB = orbitals["betaCoefficients"];
@@ -603,15 +616,22 @@ bool CjsonFormat::deserialize(std::istream& file, Molecule& molecule,
       if (properties.find("totalCharge") != properties.end()) {
         molecule.setData("totalCharge",
                          static_cast<int>(properties["totalCharge"]));
-      }
-      if (properties.find("totalSpinMultiplicity") != properties.end()) {
+      } else if (properties.find("totalSpinMultiplicity") != properties.end()) {
         molecule.setData("totalSpinMultiplicity",
                          static_cast<int>(properties["totalSpinMultiplicity"]));
+      } else if (properties.find("dipoleMoment") != properties.end()) {
+        // read the numeric array
+        json dipole = properties["dipoleMoment"];
+        if (isNumericArray(dipole) && dipole.size() == 3) {
+          Core::Variant dipoleMoment(dipole[0], dipole[1], dipole[2]);
+          molecule.setData("dipoleMoment", dipoleMoment);
+        }
       }
       // iterate through everything else
       for (auto& element : properties.items()) {
         if (element.key() == "totalCharge" ||
-            element.key() == "totalSpinMultiplicity") {
+            element.key() == "totalSpinMultiplicity" ||
+            element.key() == "dipoleMoment") {
           continue;
         }
         if (element.value().type() == json::value_t::array) {
@@ -654,16 +674,30 @@ bool CjsonFormat::deserialize(std::istream& file, Molecule& molecule,
           // std::cout << " property: " << element.key() << " = " << matrix
           //           << " size " << matrix.rows() << 'x' << matrix.cols()
           //          << std::endl;
+        } else if (element.value().type() == json::value_t::number_float) {
+          molecule.setData(element.key(), element.value().get<double>());
+        } else if (element.value().type() == json::value_t::number_integer) {
+          molecule.setData(element.key(), element.value().get<int>());
+        } else if (element.value().type() == json::value_t::boolean) {
+          molecule.setData(element.key(), element.value().get<bool>());
+        } else if (element.value().type() == json::value_t::string) {
+          molecule.setData(element.key(), element.value().get<std::string>());
         } else {
-          molecule.setData(element.key(), element.value());
-          // std::cout << " property: " << element.key() << " = "
-          //          << element.value() << " type "
-          //          << element.value().type_name() << std::endl;
+          std::cout << " cannot store property: " << element.key() << " = "
+                    << element.value() << " type "
+                    << element.value().type_name() << std::endl;
         }
       }
     }
   }
 
+  // inputParameters are calculation metadata
+  if (jsonRoot.find("inputParameters") != jsonRoot.end()) {
+    json inputParameters = jsonRoot["inputParameters"];
+    // add this as a string to the molecule data
+    molecule.setData("inputParameters", inputParameters.dump());
+  }
+
   // Partial charges are optional, but if present should be loaded.
   json partialCharges = atoms["partialCharges"];
   if (partialCharges.is_object()) {
@@ -750,6 +784,13 @@ bool CjsonFormat::serialize(std::ostream& file, const Molecule& molecule,
     if (element.first == "name" || element.first == "inchi")
       continue;
 
+    // check for "inputParameters" and handle it separately
+    if (element.first == "inputParameters") {
+      json inputParameters = json::parse(element.second.toString());
+      root["inputParameters"] = inputParameters;
+      continue;
+    }
+
     if (element.second.type() == Variant::String)
       properties[element.first] = element.second.toString().c_str();
     else if (element.second.type() == Variant::Double)
@@ -760,7 +801,15 @@ bool CjsonFormat::serialize(std::ostream& file, const Molecule& molecule,
       properties[element.first] = element.second.toInt();
     else if (element.second.type() == Variant::Bool)
       properties[element.first] = element.second.toBool();
-    else if (element.second.type() == Variant::Matrix) {
+    else if (element.second.type() == Variant::Vector) {
+      // e.g. dipole moment
+      Vector3 v = element.second.toVector3();
+      json vector;
+      vector.push_back(v.x());
+      vector.push_back(v.y());
+      vector.push_back(v.z());
+      properties[element.first] = vector;
+    } else if (element.second.type() == Variant::Matrix) {
       MatrixX m = element.second.toMatrix();
       json matrix;
       for (int i = 0; i < m.rows(); ++i) {
@@ -807,6 +856,7 @@ bool CjsonFormat::serialize(std::ostream& file, const Molecule& molecule,
   }
 
   // check for spectra data
+  // vibrations are separate
   if (molecule.spectraTypes().size() != 0) {
     json spectra, electronic, nmr;
     bool hasElectronic = false;
@@ -1057,6 +1107,18 @@ bool CjsonFormat::serialize(std::ostream& file, const Molecule& molecule,
       }
       root["atoms"]["coords"]["2d"] = coords2d;
     }
+
+    // forces if present
+    const auto forceVectors = molecule.forceVectors();
+    if (forceVectors.size() == molecule.atomCount()) {
+      json forces;
+      for (const auto& force : forceVectors) {
+        forces.push_back(force.x());
+        forces.push_back(force.y());
+        forces.push_back(force.z());
+      }
+      root["atoms"]["forces"] = forces;
+    }
   }
 
   // check for atom labels
