@@ -13,10 +13,8 @@
 #include <avogadro/core/vector.h>
 
 #include <cmath>
-#include <iomanip>
 #include <istream>
 #include <ostream>
-#include <sstream>
 #include <string>
 
 using std::map;
@@ -54,10 +52,6 @@ char swap_endian(char endian)
     return '>';
 }
 
-DcdFormat::DcdFormat() {}
-
-DcdFormat::~DcdFormat() {}
-
 bool DcdFormat::read(std::istream& inStream, Core::Molecule& mol)
 {
   /** Endian type, Buffer and Format char containers for unpacking and storing
