@@ -5,6 +5,7 @@
 
 #include "fileformat.h"
 
+#include <algorithm>
 #include <fstream>
 #include <locale>
 #include <sstream>
@@ -15,9 +16,7 @@ using std::ifstream;
 using std::locale;
 using std::ofstream;
 
-FileFormat::FileFormat() : m_mode(None), m_in(nullptr), m_out(nullptr)
-{
-}
+FileFormat::FileFormat() : m_mode(None), m_in(nullptr), m_out(nullptr) {}
 
 FileFormat::~FileFormat()
 {
@@ -25,6 +24,40 @@ FileFormat::~FileFormat()
   delete m_out;
 }
 
+bool FileFormat::validateFileName(const std::string& fileName)
+{
+  bool valid = !fileName.empty();
+
+  if (valid) {
+    // check if the filename contains invalid characters
+    static std::string forbiddenChars(",^@={}[]~!?:&*\"|#%<>$\"'();`'");
+    valid = fileName.find_first_of(forbiddenChars) == std::string::npos;
+
+    // check if the filename contains ".." which we should not allow
+    valid = valid && fileName.find("..") == std::string::npos;
+  }
+
+  // Finally check against Windows names
+  // .. we do this on all platforms because CON.cif, for example
+  // is problematic to send to a Windows user.
+  if (valid) {
+    static std::string forbiddenNames(
+      "CON PRN AUX NUL COM1 COM2 COM3 COM4 COM5 "
+      "COM6 COM7 COM8 COM9 LPT1 LPT2 LPT3 LPT4 "
+      "LPT5 LPT6 LPT7 LPT8 LPT9");
+    // case insensitive search, since con.txt is also a problem
+    // https://stackoverflow.com/a/19839371/131896
+    auto it = std::search(fileName.begin(), fileName.end(),
+                          forbiddenNames.begin(), forbiddenNames.end(),
+                          [](unsigned char ch1, unsigned char ch2) {
+                            return std::toupper(ch1) == std::toupper(ch2);
+                          });
+    valid = (it == fileName.end());
+  }
+
+  return valid;
+}
+
 bool FileFormat::open(const std::string& fileName_, Operation mode_)
 {
   close();
@@ -143,4 +176,4 @@ void FileFormat::appendError(const std::string& errorString, bool newLine)
     m_error += "\n";
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::Io
