@@ -14,8 +14,7 @@
 #include <nlohmann/json.hpp>
 
 #include <iomanip>
-#include <istream>
-#include <ostream>
+#include <iostream>
 #include <sstream>
 #include <string>
 
@@ -24,7 +23,6 @@ using json = nlohmann::json;
 using std::endl;
 using std::getline;
 using std::string;
-using std::vector;
 
 namespace Avogadro::Io {
 
@@ -32,7 +30,6 @@ using Core::Array;
 using Core::Atom;
 using Core::Elements;
 using Core::lexicalCast;
-using Core::Molecule;
 using Core::split;
 using Core::trimmed;
 
@@ -40,9 +37,33 @@ using Core::trimmed;
 using std::isalpha;
 #endif
 
-XyzFormat::XyzFormat() {}
+bool findEnergy(const std::string& buffer, double& energyValue)
+{
+  // Check for energy in the comment line
+  // orca uses  E -680.044112849966 (with spaces)
+  // xtb uses energy: -680.044112849966
+  // Open Babel uses Energy: -680.044112849966
+  std::size_t energyStart = buffer.find("energy:");
+  std::size_t offset = 7;
+  if (energyStart == std::string::npos) {
+    energyStart = buffer.find("Energy:");
+  }
+  if (energyStart == std::string::npos) {
+    energyStart = buffer.find(" E ");
+    offset = 3;
+  }
 
-XyzFormat::~XyzFormat() {}
+  if (energyStart != std::string::npos) {
+    // find the next whitespace or end of the string
+    std::size_t energyEnd = buffer.find_first_of(" \t", energyStart + offset);
+    if (energyEnd == std::string::npos)
+      energyEnd = buffer.size();
+    std::string energy = buffer.substr(energyStart + offset, energyEnd);
+    energyValue = lexicalCast<double>(energy);
+    return true;
+  }
+  return false;
+}
 
 bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
 {
@@ -60,10 +81,17 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
 
   string buffer;
   getline(inStream, buffer); // Finish the first line
-  getline(inStream, buffer);
+  getline(inStream, buffer); // comment or name or energy
   if (!buffer.empty())
     mol.setData("name", trimmed(buffer));
 
+  double energy = 0.0;
+  std::vector<double> energies;
+  if (findEnergy(buffer, energy)) {
+    mol.setData("totalEnergy", energy);
+    energies.push_back(energy);
+  }
+
   // check for Lattice= in an extended XYZ from ASE and company
   // e.g. Lattice="H11 H21 H31 H12 H22 H32 H13 H23 H33"
   // https://atomsk.univ-lille.fr/doc/en/format_xyz.html
@@ -75,7 +103,7 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
     std::size_t end = buffer.find('\"', start);
     std::string lattice = buffer.substr(start, (end - start));
 
-    vector<string> tokens(split(lattice, ' '));
+    std::vector<string> tokens(split(lattice, ' '));
     if (tokens.size() == 9) {
       Vector3 v1(lexicalCast<double>(tokens[0]), lexicalCast<double>(tokens[1]),
                  lexicalCast<double>(tokens[2]));
@@ -88,11 +116,41 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
       mol.setUnitCell(cell);
     }
   }
+  // check to see if there's an extended XYZ Properties= line
+  // e.g. Properties=species:S:1:pos:R:3
+  // https://gitlab.com/ase/ase/-/merge_requests/62
+  start = buffer.find("Properties=");
+  unsigned int chargeColumn = 0;
+  unsigned int forceColumn = 0;
+  std::vector<double> charges;
+  if (start != std::string::npos) {
+    start = start + 11; // skip over "Properties="
+    unsigned int stop = buffer.find(' ', start);
+    unsigned int length = stop - start;
+    // we want to track columns after the position
+    // (esp. charge, spin, force, velocity, etc.)
+    std::string properties = buffer.substr(start, length);
+    std::vector<string> tokens(split(properties, ':'));
+    unsigned int column = 0;
+    for (size_t i = 0; i < tokens.size(); i += 3) {
+      // we can safely assume species and pos are present
+      if (tokens[i] == "charge") {
+        chargeColumn = column;
+      } else if (tokens[i] == "force" || tokens[i] == "forces") {
+        forceColumn = column;
+      } // TODO other properties (velocity, spin, selection, etc.)
+
+      // increment column based on the count of the property
+      if (i + 2 < tokens.size()) {
+        column += lexicalCast<unsigned int>(tokens[i + 2]);
+      }
+    }
+  }
 
   // Parse atoms
   for (size_t i = 0; i < numAtoms; ++i) {
     getline(inStream, buffer);
-    vector<string> tokens;
+    std::vector<string> tokens;
     // check for tabs PR#1512
     if (buffer.find('\t') != std::string::npos)
       tokens = split(buffer, '\t');
@@ -115,6 +173,18 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
 
     Atom newAtom = mol.addAtom(atomicNum);
     newAtom.setPosition3d(pos);
+
+    // check for charge and force columns
+    if (chargeColumn > 0 && chargeColumn < tokens.size()) {
+      charges.push_back(lexicalCast<double>(tokens[chargeColumn]));
+      // we set the charges after all atoms are added
+    }
+    if (forceColumn > 0 && forceColumn < tokens.size()) {
+      Vector3 force(lexicalCast<double>(tokens[forceColumn]),
+                    lexicalCast<double>(tokens[forceColumn + 1]),
+                    lexicalCast<double>(tokens[forceColumn + 2]));
+      newAtom.setForceVector(force);
+    }
   }
 
   // Check that all atoms were handled.
@@ -129,18 +199,35 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
 
   // Do we have an animation?
   size_t numAtoms2;
-  if (getline(inStream, buffer) && (numAtoms2 = lexicalCast<int>(buffer)) &&
-      numAtoms == numAtoms2) {
-    getline(inStream, buffer); // Skip the blank
+  // check if the next frame has the same number of atoms
+  getline(inStream, buffer); // should be the number of atoms
+  if (buffer.size() == 0 || buffer[0] == '>') {
+    getline(inStream, buffer); // Orca 6 prints ">" separators
+  }
+
+  if ((numAtoms2 = lexicalCast<int>(buffer)) && numAtoms == numAtoms2) {
+    getline(inStream, buffer); // comment line
+    // check for properties in the comment line
+    if (findEnergy(buffer, energy)) {
+      energies.push_back(energy);
+    }
+
     mol.setCoordinate3d(mol.atomPositions3d(), 0);
     int coordSet = 1;
+    bool done = false;
     while (numAtoms == numAtoms2) {
       Array<Vector3> positions;
       positions.reserve(numAtoms);
 
       for (size_t i = 0; i < numAtoms; ++i) {
         getline(inStream, buffer);
-        vector<string> tokens(split(buffer, ' '));
+        if (inStream.eof()) {
+          numAtoms2 = 0;
+          done = true;
+          break; // break this inner loop
+        }
+
+        std::vector<string> tokens(split(buffer, ' '));
         if (tokens.size() < 4) {
           appendError("Not enough tokens in this line: " + buffer);
           return false;
@@ -151,15 +238,32 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
         positions.push_back(pos);
       }
 
-      mol.setCoordinate3d(positions, coordSet++);
+      if (!done)
+        mol.setCoordinate3d(positions, coordSet++);
+
+      if (getline(inStream, buffer)) {
+        if (inStream.eof()) {
+          numAtoms2 = 0;
+          break; // break this inner loop
+        }
+
+        if (buffer.size() == 0 || buffer[0] == '>')
+          getline(inStream, buffer); // Orca 6 prints ">" separators
+        if (inStream.eof()) {
+          numAtoms2 = 0;
+          break; // break this inner loop
+        }
 
-      if (!getline(inStream, buffer)) {
         numAtoms2 = lexicalCast<int>(buffer);
-        if (numAtoms == numAtoms2)
+        if (numAtoms != numAtoms2)
           break;
       }
 
       std::getline(inStream, buffer); // Skip the blank
+      // check for energies
+      if (findEnergy(buffer, energy)) {
+        energies.push_back(energy);
+      }
       positions.clear();
     }
   }
@@ -170,6 +274,19 @@ bool XyzFormat::read(std::istream& inStream, Core::Molecule& mol)
     mol.perceiveBondOrders();
   }
 
+  // have to set the charges after creating bonds
+  // (since modifying bonds invalidates the partial charges)
+  if (!charges.empty()) {
+    MatrixX chargesMatrix = MatrixX::Zero(mol.atomCount(), 1);
+    for (size_t i = 0; i < charges.size(); ++i) {
+      chargesMatrix(i, 0) = charges[i];
+    }
+    mol.setPartialCharges("From File", chargesMatrix);
+  }
+
+  if (energies.size() > 1)
+    mol.setData("energies", energies);
+
   return true;
 }
 
@@ -212,12 +329,12 @@ bool XyzFormat::write(std::ostream& outStream, const Core::Molecule& mol)
     }
 
     outStream << std::setw(3) << std::left
-              << Elements::symbol(atom.atomicNumber()) << " " << std::setw(10)
-              << std::right << std::fixed << std::setprecision(5)
-              << atom.position3d().x() << " " << std::setw(10) << std::right
-              << std::fixed << std::setprecision(5) << atom.position3d().y()
-              << " " << std::setw(10) << std::right << std::fixed
-              << std::setprecision(5) << atom.position3d().z() << "\n";
+              << Elements::symbol(atom.atomicNumber()) << " " << std::setw(15)
+              << std::right << std::fixed << std::setprecision(10)
+              << atom.position3d().x() << " " << std::setw(15) << std::right
+              << std::fixed << std::setprecision(10) << atom.position3d().y()
+              << " " << std::setw(15) << std::right << std::fixed
+              << std::setprecision(10) << atom.position3d().z() << "\n";
   }
 
   return true;
@@ -227,6 +344,7 @@ std::vector<std::string> XyzFormat::fileExtensions() const
 {
   std::vector<std::string> ext;
   ext.emplace_back("xyz");
+  ext.emplace_back("exyz");
   ext.emplace_back("extxyz");
   return ext;
 }
