@@ -21,8 +21,8 @@
 
 namespace Avogadro::MoleQueue {
 
-using QtGui::PythonScript;
 using QtGui::GenericHighlighter;
+using QtGui::PythonScript;
 
 InputGenerator::InputGenerator(const QString& scriptFilePath_, QObject* parent_)
   : QObject(parent_), m_interpreter(new PythonScript(scriptFilePath_, this)),
@@ -36,10 +36,6 @@ InputGenerator::InputGenerator(QObject* parent_)
 {
 }
 
-InputGenerator::~InputGenerator()
-{
-}
-
 bool InputGenerator::debug() const
 {
   return m_interpreter->debug();
@@ -118,7 +114,7 @@ void InputGenerator::setScriptFilePath(const QString& scriptFile)
 
 void InputGenerator::reset()
 {
-  m_interpreter->setDefaultPythonInterpretor();
+  m_interpreter->setDefaultPythonInterpreter();
   m_interpreter->setScriptFilePath(QString());
   m_moleculeExtension = "Unknown";
   m_displayName = QString();
@@ -279,7 +275,7 @@ bool InputGenerator::generateInput(const QJsonObject& options_,
     m_errors << tr("Response must be a JSON object at top-level.");
   }
 
-  if (result == false)
+  if (!result)
     m_errors << tr("Script output:\n%1").arg(QString(json));
 
   return result;
@@ -355,7 +351,8 @@ bool InputGenerator::insertMolecule(QJsonObject& json,
 
   std::string str;
   if (!format->writeString(str, mol)) {
-    m_errors << tr("Error saving molecule representation to string: %1", "%1 = error message")
+    m_errors << tr("Error saving molecule representation to string: %1",
+                   "%1 = error message")
                   .arg(QString::fromStdString(format->error()));
     return false;
   }
@@ -409,12 +406,15 @@ void InputGenerator::replaceKeywords(QString& str,
 
   // Find each coordinate block keyword in the file, then generate and replace
   // it with the appropriate values.
-  QRegExp coordParser(R"(\$\$coords:([^\$]*)\$\$)");
+  QRegularExpression coordParser(R"(\$\$coords:([^\$]*)\$\$)");
+  QRegularExpressionMatch match;
   int ind = 0;
-  while ((ind = coordParser.indexIn(str, ind)) != -1) {
+  // Not sure while this needs to be a while statement since we replace all in
+  // one go? We never iterate ind...
+  while ((match = coordParser.match(str, ind)).hasMatch()) {
     // Extract spec and prepare the replacement
-    const QString keyword = coordParser.cap(0);
-    const QString spec = coordParser.cap(1);
+    const QString keyword = match.captured(0);
+    const QString spec = match.captured(1);
 
     // Replace all blocks with this signature
     str.replace(keyword, generateCoordinateBlock(spec, mol));
@@ -522,7 +522,7 @@ bool InputGenerator::parseRules(const QJsonArray& json,
     GenericHighlighter::Rule& rule = highligher.addRule();
 
     foreach (QJsonValue patternVal, patternsArray) {
-      QRegExp pattern;
+      QRegularExpression pattern;
       if (!parsePattern(patternVal, pattern)) {
         qDebug() << "Error while parsing pattern:" << '\n'
                  << QString(QJsonDocument(patternVal.toObject()).toJson());
@@ -644,35 +644,49 @@ bool InputGenerator::parseFormat(const QJsonObject& json,
 }
 
 bool InputGenerator::parsePattern(const QJsonValue& json,
-                                  QRegExp& pattern) const
+                                  QRegularExpression& pattern) const
 {
   if (!json.isObject())
     return false;
 
   QJsonObject patternObj(json.toObject());
+  QString regexPattern;
+  QRegularExpression::PatternOptions patternOptions =
+    QRegularExpression::NoPatternOption;
 
-  if (patternObj.contains("regexp") && patternObj.value("regexp").isString()) {
-    pattern.setPatternSyntax(QRegExp::RegExp2);
-    pattern.setPattern(patternObj.value("regexp").toString());
-  } else if (patternObj.contains("wildcard") &&
-             patternObj.value("wildcard").isString()) {
-    pattern.setPatternSyntax(QRegExp::WildcardUnix);
-    pattern.setPattern(patternObj.value("wildcard").toString());
-  } else if (patternObj.contains("string") &&
-             patternObj.value("string").isString()) {
-    pattern.setPatternSyntax(QRegExp::FixedString);
-    pattern.setPattern(patternObj.value("string").toString());
+  if (patternObj.contains(QStringLiteral("regexp")) &&
+      patternObj.value(QStringLiteral("regexp")).isString()) {
+    // Use the provided regular expression as-is
+    regexPattern = patternObj.value(QStringLiteral("regexp")).toString();
+  } else if (patternObj.contains(QStringLiteral("wildcard")) &&
+             patternObj.value(QStringLiteral("wildcard")).isString()) {
+    // Convert wildcard pattern (* -> .* and ? -> .)
+    QString wildcard = patternObj.value(QStringLiteral("wildcard")).toString();
+    regexPattern = QRegularExpression::escape(wildcard)
+                     .replace("\\*", ".*")
+                     .replace("\\?", ".");
+  } else if (patternObj.contains(QStringLiteral("string")) &&
+             patternObj.value(QStringLiteral("string")).isString()) {
+    // Escape the string so it is treated literally in the regex
+    regexPattern = QRegularExpression::escape(
+      patternObj.value(QStringLiteral("string")).toString());
   } else {
     return false;
   }
 
-  if (patternObj.contains("caseSensitive")) {
-    pattern.setCaseSensitivity(patternObj.value("caseSensitive").toBool(true)
-                                 ? Qt::CaseSensitive
-                                 : Qt::CaseInsensitive);
+  // Set case sensitivity if specified
+  if (patternObj.contains(QStringLiteral("caseSensitive"))) {
+    bool caseSensitive =
+      patternObj.value(QStringLiteral("caseSensitive")).toBool(true);
+    if (!caseSensitive) {
+      patternOptions |= QRegularExpression::CaseInsensitiveOption;
+    }
   }
 
-  return true;
+  // Set the final pattern with options
+  pattern = QRegularExpression(regexPattern, patternOptions);
+
+  return pattern.isValid();
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::MoleQueue
