@@ -40,6 +40,37 @@ JsonWidget::~JsonWidget() {}
 
 void JsonWidget::setMolecule(QtGui::Molecule* mol)
 {
+  if (m_molecule != nullptr) {
+    // update charge and multiplicity if needed
+    int charge = static_cast<int>(m_molecule->totalCharge());
+    int multiplicity = static_cast<int>(m_molecule->totalSpinMultiplicity());
+
+    setOption("Charge", charge);
+    setOption("Multiplicity", multiplicity);
+
+    // check the molecule for "inputParameters" from CJSON
+    // e.g.
+    // https://github.com/OpenChemistry/chemicaljson/blob/main/chemicaljson.py#L130
+    if (m_molecule->hasData("inputParameters")) {
+      QByteArray data(m_molecule->data("inputParameters").toString().c_str());
+      QJsonDocument doc = QJsonDocument::fromJson(data);
+      if (!doc.isNull() && doc.isObject()) {
+        QJsonObject inputParameters = doc.object();
+        // check for a few known keys
+        if (inputParameters.contains("processors"))
+          setOption("Processor Cores", inputParameters["processors"].toInt());
+        else if (inputParameters.contains("memory"))
+          setOption("Memory", inputParameters["memory"].toInt());
+        else if (inputParameters.contains("basis"))
+          setOption("Basis", inputParameters["basis"].toString());
+        else if (inputParameters.contains("functional"))
+          setOption("Theory", inputParameters["functional"].toString());
+        else if (inputParameters.contains("task"))
+          setOption("Calculation Type", inputParameters["task"].toString());
+      }
+    }
+  }
+
   if (mol == m_molecule)
     return;
 
@@ -816,8 +847,11 @@ QJsonObject JsonWidget::collectOptions() const
 
 void JsonWidget::applyOptions(const QJsonObject& opts)
 {
-  foreach (const QString& label, opts.keys())
+  foreach (const QString& label, opts.keys()) {
     setOption(label, opts[label]);
+
+    qDebug() << "Setting option" << label << "to" << opts[label];
+  }
 }
 
 QString JsonWidget::generateJobTitle() const
