@@ -11,6 +11,7 @@
 
 #include <Eigen/Geometry>
 #include <QtCore/QAbstractItemModel>
+#include <QtGui/QIcon>
 
 namespace Avogadro {
 namespace QtGui {
@@ -69,6 +70,14 @@ public slots:
 private:
   QString getTranslatedName(const std::string& name) const;
   size_t m_item;
+
+  QIcon m_plusIcon;
+  QIcon m_dotsIcon;
+  QIcon m_previewIcon;
+  QIcon m_previewDashedIcon;
+  QIcon m_lockIcon;
+  QIcon m_openLockIcon;
+  QIcon m_removeIcon;
 };
 
 } // namespace QtGui
