@@ -173,12 +173,27 @@ bool RWMolecule::setAtomPositions3d(const Core::Array<Vector3>& pos,
 bool RWMolecule::setAtomLabel(Index atomId, const std::string& label,
                               const QString& undoText)
 {
+  if (atomId >= atomCount())
+    return false;
+
   auto* comm = new ModifyAtomLabelCommand(*this, atomId, label);
   comm->setText(undoText);
   m_undoStack.push(comm);
   return true;
 }
 
+bool RWMolecule::setBondLabel(Index bondId, const std::string& label,
+                              const QString& undoText)
+{
+  if (bondId >= bondCount())
+    return false;
+
+  auto* comm = new ModifyBondLabelCommand(*this, bondId, label);
+  comm->setText(undoText);
+  m_undoStack.push(comm);
+  return true;
+}
+
 bool RWMolecule::setAtomPosition3d(Index atomId, const Vector3& pos,
                                    const QString& undoText)
 {
@@ -389,7 +404,7 @@ void RWMolecule::addUnitCell()
   m_molecule.setUnitCell(cell);
 
   auto* comm = new AddUnitCellCommand(*this, *m_molecule.unitCell());
-  comm->setText(tr("Add Unit Cell"));
+  comm->setText(tr("Add Unit Cell…"));
   m_undoStack.push(comm);
   emitChanged(Molecule::UnitCell | Molecule::Added);
 }
