@@ -11,8 +11,8 @@ ScenePlugin::ScenePlugin(QObject* parent_) : QObject(parent_) {}
 
 ScenePlugin::~ScenePlugin() {}
 
-void ScenePlugin::process(const QtGui::Molecule& molecule,
-                          Rendering::GroupNode& node)
+void ScenePlugin::process(const QtGui::Molecule&,
+                          Rendering::GroupNode&)
 {}
 
 void ScenePlugin::processEditable(const RWMolecule&, Rendering::GroupNode&) {}
