@@ -1,15 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTGUI_SCRIPTLOADER_H
@@ -27,6 +18,9 @@ namespace QtGui {
 /**
  * @brief The ScriptLoader class finds and verifies different types of
  * python utility scripts.
+ *
+ * For example, finding all the "charge" scripts
+ * auto chargeScripts = ScriptLoader::scriptList("charge");
  */
 class AVOGADROQTGUI_EXPORT ScriptLoader : public QObject
 {
@@ -39,7 +33,7 @@ public:
   /**
    * @return A map of name -> path for all scripts of the requested @arg type
    */
-  static QMap<QString, QString> scriptList(const QString& type);
+  static QMultiMap<QString, QString> scriptList(const QString& type);
 
   static bool queryProgramName(const QString& scriptFilePath,
                                QString& displayName);
