@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTPLUGINS_APBS_OPENDXREADER_H
@@ -36,12 +25,12 @@ public:
   /**
    * Constructor for OpenDxReader.
    */
-  OpenDxReader();
+  OpenDxReader() = default;
 
   /**
    * Destructor for OpenDxReader.
    */
-  ~OpenDxReader();
+  ~OpenDxReader() = default;
 
   /**
    * Reads the file with the given @fileName. Returns false if an error
@@ -61,7 +50,7 @@ public:
   Core::Cube* cube() const;
 
 private:
-  Core::Cube* m_cube;
+  Core::Cube* m_cube = nullptr;
   QString m_errorString;
 };
 }
