@@ -56,10 +56,6 @@ using QtGui::RWMolecule;
 using Rendering::ArcSector;
 using Rendering::ArcStrip;
 using Rendering::GeometryNode;
-using Rendering::GroupNode;
-using Rendering::Identifier;
-using Rendering::LineStripGeometry;
-using Rendering::MeshGeometry;
 using Rendering::Quad;
 using Rendering::QuadOutline;
 
@@ -118,16 +114,17 @@ BondCentricTool::BondCentricTool(QObject* parent_)
     m_molecule(nullptr), m_renderer(nullptr), m_moveState(IgnoreMove),
     m_planeSnapIncr(10.f), m_snapPlaneToBonds(true)
 {
+  QString shortcut = tr("Ctrl+7", "control-key 7");
   m_activateAction->setText(tr("Bond-Centric Manipulation"));
   m_activateAction->setToolTip(
-    tr("Bond Centric Manipulation Tool\n\n"
+    tr("Bond Centric Manipulation Tool \t(%1)\n\n"
        "Left Mouse: \tClick and drag to rotate the view.\n"
        "Middle Mouse: \tClick and drag to zoom in or out.\n"
        "Right Mouse: \tClick and drag to move the view.\n"
        "Double-Click: \tReset the view.\n\n"
        "Left Click & Drag on a Bond to set the Manipulation Plane:\n"
        "Left Click & Drag one of the Atoms in the Bond to change the angle\n"
-       "Right Click & Drag one of the Atoms in the Bond to change the length"));
+       "Right Click & Drag one of the Atoms in the Bond to change the length").arg(shortcut));
   setIcon();
 }
 
