@@ -6,8 +6,6 @@
 
 #include <avogadro/qtgui/extensionplugin.h>
 
-class QStringList;
-
 namespace Avogadro {
 class HistogramWidget;
 namespace QtPlugins {
@@ -23,16 +21,18 @@ public:
   explicit ColorOpacityMap(QObject* parent_ = nullptr);
   ~ColorOpacityMap();
 
-  QString name() const { return tr("ColorOpacityMap"); }
-  QString description() const;
-  QList<QAction*> actions() const;
-  QStringList menuPath(QAction*) const;
+  QString name() const override { return tr("ColorOpacityMap"); }
+  QString description() const override;
+  QList<QAction*> actions() const override;
+  QStringList menuPath(QAction*) const override;
 
 public slots:
-  void setMolecule(QtGui::Molecule* mol);
+  void setMolecule(QtGui::Molecule* mol) override;
 
   void moleculeChanged(unsigned int changes);
 
+  void setActiveWidget(QWidget* widget) override;
+
 private slots:
   void updateActions();
 
@@ -50,6 +50,7 @@ private:
   HistogramWidget* m_histogramWidget = nullptr;
   QScopedPointer<QAction> m_displayDialogAction;
 
+  bool m_vtkWidget = false;
   QWidget* m_activeWidget = nullptr;
 };
 
