@@ -22,7 +22,8 @@ class ComDialog : public QDialog
   Q_OBJECT
 
 public:
-  ComDialog(QWidget* parent = nullptr, Qt::WindowFlags f = 0);
+  explicit ComDialog(QWidget* parent = nullptr,
+                     Qt::WindowFlags f = Qt::WindowFlags());
   ~ComDialog() override;
 
   HistogramWidget* histogramWidget();
