@@ -14,7 +14,7 @@
 #include <avogadro/molequeue/client/jobobject.h>
 
 #include <QtCore/QDebug>
-#include <QtWidgets/QAction>
+#include <QAction>
 #include <QtWidgets/QMessageBox>
 
 namespace Avogadro {
