@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2016 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "supercelldialog.h"
@@ -23,10 +12,8 @@
 #include <avogadro/qtgui/molecule.h>
 #include <avogadro/qtgui/rwmolecule.h>
 
-using Avogadro::Core::CrystalTools;
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 SupercellDialog::SupercellDialog(QWidget* p)
   : QDialog(p), m_ui(new Ui::SupercellDialog)
@@ -59,5 +46,4 @@ bool SupercellDialog::buildSupercell(Avogadro::QtGui::Molecule& mol)
   return true;
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
