@@ -165,27 +165,30 @@ GamessHighlighter::GamessHighlighter(QTextDocument* parent_)
              << R"(\s\$DATA\b)";
   rule.format = m_keywordFormat;
   foreach (const QString& pattern, m_keywords) {
-    rule.pattern = QRegExp(pattern);
+    rule.pattern = QRegularExpression(pattern);
     m_highlightingRules.append(rule);
   }
-  rule.pattern = QRegExp(R"(\s\$END\b)");
+  rule.pattern = QRegularExpression(R"(\s\$END\b)");
   m_highlightingRules.append(rule);
 
   m_singleLineCommentFormat.setForeground(Qt::green);
-  rule.pattern = QRegExp("![^\n]*");
+  rule.pattern = QRegularExpression("![^\n]*");
   rule.format = m_singleLineCommentFormat;
   m_highlightingRules.append(rule);
 
   m_numberFormat.setForeground(Qt::blue);
-  rule.pattern = QRegExp(R"((\b|[\s-])[0-9]+\.([0-9]+\b)?|\.[0-9]+\b)");
+  rule.pattern =
+    QRegularExpression(R"((\b|[\s-])[0-9]+\.([0-9]+\b)?|\.[0-9]+\b)");
   rule.format = m_numberFormat;
   m_highlightingRules.append(rule);
 
   m_numberFormat.setForeground(Qt::blue);
-  rule.pattern = QRegExp(R"((\b|[\s-])[0-9]+\.([0-9]+\b)?|\.[0-9]+\b)");
+  rule.pattern =
+    QRegularExpression(R"((\b|[\s-])[0-9]+\.([0-9]+\b)?|\.[0-9]+\b)");
   rule.format = m_numberFormat;
   m_highlightingRules.append(rule);
-  rule.pattern = QRegExp(R"((\b|[\s-])[0-9]+([0-9]+\b)?|\.[0-9]+\b)");
+  rule.pattern =
+    QRegularExpression(R"((\b|[\s-])[0-9]+([0-9]+\b)?|\.[0-9]+\b)");
   rule.format = m_numberFormat;
   m_highlightingRules.append(rule);
 
@@ -198,10 +201,11 @@ GamessHighlighter::GamessHighlighter(QTextDocument* parent_)
 void GamessHighlighter::highlightBlock(const QString& text)
 {
   // Single line comments
-  QRegExp pattern("![^\n]*");
-  int commentIndex = pattern.indexIn(text);
-  if (commentIndex >= 0)
-    setFormat(commentIndex, pattern.matchedLength(), m_singleLineCommentFormat);
+  QRegularExpression pattern("![^\n]*");
+  QRegularExpressionMatch commentMatch = pattern.match(text);
+  if (commentMatch.hasMatch())
+    setFormat(commentMatch.capturedStart(), commentMatch.capturedLength(),
+              m_singleLineCommentFormat);
 
   setCurrentBlockState(0);
 
@@ -209,11 +213,12 @@ void GamessHighlighter::highlightBlock(const QString& text)
   int keywordLength = 0;
   if (previousBlockState() != 1) {
     foreach (const QString& regexString, m_keywords) {
-      QRegExp expression(regexString);
-      expression.setCaseSensitivity(Qt::CaseInsensitive);
-      startIndex = expression.indexIn(text);
-      keywordLength = expression.matchedLength();
-      if (startIndex >= 0) {
+      QRegularExpression startExpression(
+        regexString, QRegularExpression::CaseInsensitiveOption);
+      QRegularExpressionMatch startMatch = startExpression.match(text);
+      startIndex = startMatch.capturedStart();
+      keywordLength = startMatch.capturedLength();
+      if (startMatch.hasMatch()) {
         setFormat(startIndex, keywordLength, m_keywordFormat);
         break;
       }
@@ -221,26 +226,29 @@ void GamessHighlighter::highlightBlock(const QString& text)
   }
 
   while (startIndex >= 0) {
-    QRegExp endExpression(R"(\s\$END\b)");
-    endExpression.setCaseSensitivity(Qt::CaseInsensitive);
-    int endIndex = endExpression.indexIn(text, startIndex);
+    QRegularExpression endExpression(R"(\s\$END\b)",
+                                     QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch match = endExpression.match(text, startIndex);
+    int endIndex = match.capturedStart();
     int blockLength;
     if (endIndex == -1) {
       setCurrentBlockState(1);
       blockLength = text.length() - startIndex - keywordLength;
     } else {
-      setFormat(endIndex, endExpression.matchedLength(), m_keywordFormat);
+      setFormat(endIndex, match.capturedLength(), m_keywordFormat);
       blockLength = endIndex - startIndex - keywordLength;
     }
     setFormat(startIndex + keywordLength, blockLength, m_inDataBlockFormat);
     bool found = false;
     foreach (const QString& regexString, m_keywords) {
-      QRegExp expression(regexString);
-      int index = expression.indexIn(text, startIndex + blockLength);
+      QRegularExpression newExpression(regexString);
+      QRegularExpressionMatch newMatch =
+        newExpression.match(text, startIndex + blockLength);
+      int index = newMatch.capturedStart();
       if (index > startIndex) {
         found = true;
         startIndex = index;
-        keywordLength = expression.matchedLength();
+        keywordLength = newMatch.capturedLength();
         setFormat(startIndex, keywordLength, m_keywordFormat);
         break;
       }
@@ -252,13 +260,16 @@ void GamessHighlighter::highlightBlock(const QString& text)
   if (previousBlockState() ==
       1) { // Anything outside of data blocks is a comment
     foreach (const HighlightingRule& rule, m_highlightingRules) {
-      QRegExp expression(rule.pattern);
-      expression.setCaseSensitivity(Qt::CaseInsensitive);
-      int index = text.indexOf(expression);
-      while (index >= 0) {
-        int length = expression.matchedLength();
+      QRegularExpression otherExpression(rule.pattern);
+      otherExpression.setPatternOptions(
+        QRegularExpression::CaseInsensitiveOption);
+      QRegularExpressionMatchIterator iterator =
+        otherExpression.globalMatch(text);
+      while (iterator.hasNext()) {
+        QRegularExpressionMatch otherMatch = iterator.next();
+        int index = otherMatch.capturedStart();
+        int length = otherMatch.capturedLength();
         setFormat(index, length, rule.format);
-        index = text.indexOf(expression, index + length);
       }
     }
   }
@@ -268,4 +279,4 @@ void GamessHighlighter::highlightBlock(const QString& text)
     setFormat(80, text.length(), m_errorFormat);
 }
 
-} // End namespace Avogadro
+} // namespace Avogadro::QtPlugins
