@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2012 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "gamessinputdialog.h"
@@ -39,12 +28,11 @@
 #include <QtCore/QString>
 #include <QtCore/QTimer>
 
+using Avogadro::MoleQueue::JobObject;
 using Avogadro::MoleQueue::MoleQueueDialog;
 using Avogadro::MoleQueue::MoleQueueManager;
-using Avogadro::MoleQueue::JobObject;
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 enum CalculateOption
 {
@@ -129,9 +117,7 @@ GamessInputDialog::GamessInputDialog(QWidget* parent_, Qt::WindowFlags f)
   updatePreviewText();
 }
 
-GamessInputDialog::~GamessInputDialog()
-{
-}
+GamessInputDialog::~GamessInputDialog() {}
 
 void GamessInputDialog::setMolecule(QtGui::Molecule* mol)
 {
@@ -184,9 +170,7 @@ void GamessInputDialog::connectBasic()
           SLOT(updatePreviewText()));
 }
 
-void GamessInputDialog::connectPreview()
-{
-}
+void GamessInputDialog::connectPreview() {}
 
 void GamessInputDialog::connectButtons()
 {
@@ -408,7 +392,7 @@ QString GamessInputDialog::generateJobTitle() const
 
   // Merge theory/basis into theory
   theory += "/" + basis;
-  theory.replace(QRegExp("\\s+"), "");
+  theory.replace(QRegularExpression("\\s+"), "");
 
   return QString("%1 | %2 | %3").arg(formula, calculation, theory);
 }
@@ -445,16 +429,14 @@ void GamessInputDialog::updatePreviewText()
   if (title.isEmpty())
     title = generateJobTitle();
 
-  CalculateOption calculate(
+  auto calculate(
     static_cast<CalculateOption>(ui.calculateCombo->currentIndex()));
-  TheoryOption theory(
-    static_cast<TheoryOption>(ui.theoryCombo->currentIndex()));
-  BasisOption basis(static_cast<BasisOption>(ui.basisCombo->currentIndex()));
-  StateOption state(static_cast<StateOption>(ui.stateCombo->currentIndex()));
-  MultiplicityOption multiplicity(
+  auto theory(static_cast<TheoryOption>(ui.theoryCombo->currentIndex()));
+  auto basis(static_cast<BasisOption>(ui.basisCombo->currentIndex()));
+  auto state(static_cast<StateOption>(ui.stateCombo->currentIndex()));
+  auto multiplicity(
     static_cast<MultiplicityOption>(ui.multiplicityCombo->currentIndex()));
-  ChargeOption charge(
-    static_cast<ChargeOption>(ui.chargeCombo->currentIndex()));
+  auto charge(static_cast<ChargeOption>(ui.chargeCombo->currentIndex()));
 
   // Disable basis selection for semiempirical methods.
   ui.basisCombo->setEnabled(theory != TheoryAM1 && theory != TheoryPM3);
@@ -750,5 +732,4 @@ void GamessInputDialog::updateTitlePlaceholder()
   ui.titleEdit->setPlaceholderText(generateJobTitle());
 }
 
-} // end namespace QtPlugins
-} // end namespace Avogadro
+} // namespace Avogadro::QtPlugins
