@@ -625,14 +625,14 @@ QString LammpsInputDialog::generateInputDeck()
   mol << "\n" << getWaterPotential(m_waterPotential) << "\n";
 
   mol << "# Settings\n";
-  mol << "velocity       all create " << fixed << qSetRealNumberPrecision(2)
+  mol << "velocity       all create " << Qt::fixed << qSetRealNumberPrecision(2)
       << m_velocityTemp << " "
       << "4928459 "
       << "rot " << getZeroL() << " "
       << "mom " << getZeroMOM() << " "
       << "dist " << getVelocityDist(m_velocityDist) << "\n";
   mol << getEnsemble(m_ensemble) << "\n";
-  mol << "timestep       " << fixed << qSetRealNumberPrecision(1) << m_timeStep
+  mol << "timestep       " << Qt::fixed << qSetRealNumberPrecision(1) << m_timeStep
       << "\n";
   mol << "\n";
 
@@ -853,8 +853,8 @@ QString LammpsInputDialog::getEnsemble(ensemble t)
       QString ensembleInput;
       QTextStream fix(&ensembleInput);
       fix << "fix            ensemble all nvt"
-          << " temp " << fixed << qSetRealNumberPrecision(2) << m_temperature
-          << " " << fixed << qSetRealNumberPrecision(2) << m_temperature
+          << " temp " << Qt::fixed << qSetRealNumberPrecision(2) << m_temperature
+          << " " << Qt::fixed << qSetRealNumberPrecision(2) << m_temperature
           << " 100 "
           << "tchain " << m_nhChain << "\n";
       return ensembleInput;
@@ -869,8 +869,8 @@ QString LammpsInputDialog::getEnsemble(ensemble t)
       QString ensembleInput;
       QTextStream fix(&ensembleInput);
       fix << "fix            ensemble all nvt"
-          << " temp " << fixed << qSetRealNumberPrecision(2) << m_temperature
-          << " " << fixed << qSetRealNumberPrecision(2) << m_temperature
+          << " temp " << Qt::fixed << qSetRealNumberPrecision(2) << m_temperature
+          << " " << Qt::fixed << qSetRealNumberPrecision(2) << m_temperature
           << " 100 "
           << "tchain " << m_nhChain << "\n";
       return ensembleInput;
