@@ -46,11 +46,13 @@ Manipulator::Manipulator(QObject* parent_)
     m_toolWidget(new ManipulateWidget(dynamic_cast<QWidget*>(parent_))),
     m_currentAction(Nothing)
 {
+  QString shortcut = tr("Ctrl+6", "control-key 6");
   m_activateAction->setText(tr("Manipulate"));
   m_activateAction->setToolTip(
-    tr("Manipulation Tool\n\n"
+    tr("Manipulation Tool \t(%1)\n\n"
        "Left Mouse: \tClick and drag to move atoms\n"
-       "Right Mouse: \tClick and drag to rotate selected atoms.\n"));
+       "Right Mouse: \tClick and drag to rotate atoms.\n")
+      .arg(shortcut));
   setIcon();
   connect(m_toolWidget->buttonBox, SIGNAL(clicked(QAbstractButton*)), this,
           SLOT(buttonClicked(QAbstractButton*)));
@@ -99,20 +101,27 @@ void Manipulator::buttonClicked(QAbstractButton* button)
     return;
   }
 
+  bool moveSelected = (m_toolWidget->moveComboBox->currentIndex() == 0);
+
   // apply values
   Vector3 delta(m_toolWidget->xTranslateSpinBox->value(),
                 m_toolWidget->yTranslateSpinBox->value(),
                 m_toolWidget->zTranslateSpinBox->value());
 
-  translate(delta);
+  translate(delta, moveSelected);
 
   Vector3 rotation(m_toolWidget->xRotateSpinBox->value(),
                    m_toolWidget->yRotateSpinBox->value(),
                    m_toolWidget->zRotateSpinBox->value());
   Vector3 center(0.0, 0.0, 0.0);
 
-  // Check if we're rotating around the origin or the centroid
+  // Check if we're rotating around the origin, the molecule centroid
+  // or the center of selected atoms
+  // == 0 is the default = origin
   if (m_toolWidget->rotateComboBox->currentIndex() == 1) {
+    // molecule centroid
+    center = m_molecule->molecule().centerOfGeometry();
+  } else if (m_toolWidget->rotateComboBox->currentIndex() == 2) {
     // center of selected atoms
     unsigned long selectedAtomCount = 0;
     for (Index i = 0; i < m_molecule->atomCount(); ++i) {
@@ -124,16 +133,13 @@ void Manipulator::buttonClicked(QAbstractButton* button)
     }
     if (selectedAtomCount > 0)
       center /= selectedAtomCount;
-
-  } else {
-    center = m_molecule->molecule().centerOfGeometry();
   }
 
   // Settings are in degrees
 #ifndef DEG_TO_RAD
 #define DEG_TO_RAD 0.0174532925
 #endif
-  rotate(rotation * DEG_TO_RAD, center);
+  rotate(rotation * DEG_TO_RAD, center, moveSelected);
 
   m_molecule->emitChanged(Molecule::Atoms | Molecule::Modified);
 }
@@ -230,10 +236,17 @@ QUndoCommand* Manipulator::mouseReleaseEvent(QMouseEvent* e)
 
 QUndoCommand* Manipulator::mouseMoveEvent(QMouseEvent* e)
 {
+  // if we're dragging through empty space, just return and ignore
+  // (e.g., fall back to the navigate tool)
+  const Core::Molecule* mol = &m_molecule->molecule();
+  if (mol->isSelectionEmpty() && m_object.type == Rendering::InvalidType) {
+    e->ignore();
+    return nullptr;
+  }
+
   updatePressedButtons(e, false);
   e->ignore();
 
-  const Core::Molecule* mol = &m_molecule->molecule();
   Vector2f windowPos(e->localPos().x(), e->localPos().y());
 
   if (mol->isSelectionEmpty() && m_object.type == Rendering::AtomType &&
@@ -280,10 +293,12 @@ QUndoCommand* Manipulator::mouseMoveEvent(QMouseEvent* e)
   return nullptr;
 }
 
-void Manipulator::translate(Vector3 delta)
+void Manipulator::translate(Vector3 delta, bool moveSelected)
 {
   for (Index i = 0; i < m_molecule->atomCount(); ++i) {
-    if (!m_molecule->atomSelected(i))
+    if (moveSelected && !m_molecule->atomSelected(i))
+      continue;
+    else if (!moveSelected && m_molecule->atomSelected(i))
       continue;
 
     Vector3 currentPos = m_molecule->atomPosition3d(i);
@@ -291,7 +306,7 @@ void Manipulator::translate(Vector3 delta)
   }
 }
 
-void Manipulator::rotate(Vector3 delta, Vector3 centroid)
+void Manipulator::rotate(Vector3 delta, Vector3 centroid, bool moveSelected)
 {
   // Rotate the selected atoms about the center
   // rotate only selected primitives
@@ -311,7 +326,9 @@ void Manipulator::rotate(Vector3 delta, Vector3 centroid)
   fragmentRotation.translate(-centroid);
 
   for (Index i = 0; i < m_molecule->atomCount(); ++i) {
-    if (!m_molecule->atomSelected(i))
+    if (moveSelected && !m_molecule->atomSelected(i))
+      continue;
+    else if (!moveSelected && m_molecule->atomSelected(i))
       continue;
 
     Vector3 currentPos = m_molecule->atomPosition3d(i);
