@@ -66,14 +66,9 @@ void Meshes::process(const QtGui::Molecule& mol, GroupNode& node)
     auto* geometry = new GeometryNode;
     node.addChild(geometry);
 
+    // Handle the first mesh
     const Mesh* mesh = mol.mesh(0);
-
-    /// @todo Allow use of MeshGeometry without an index array when all vertices
-    /// form explicit triangles.
-    // Create index array:
-    Sequence indexGenerator;
-    Core::Array<unsigned int> indices(mesh->numVertices());
-    std::generate(indices.begin(), indices.end(), indexGenerator);
+    Core::Array<Vector3f> triangles = mesh->triangles();
 
     bool hasColors = (mesh->colors().size() != 0);
 
@@ -85,32 +80,41 @@ void Meshes::process(const QtGui::Molecule& mol, GroupNode& node)
       auto colors = mesh->colors();
       Core::Array<Vector3ub> colorsRGB(colors.size());
       for (size_t i = 0; i < colors.size(); i++)
-        colorsRGB[i] = Vector3ub(colors[i].red() * 255, colors[i].green() * 255,
-                                 colors[i].blue() * 255);
+        colorsRGB[i] = Vector3ub(static_cast<unsigned char>(colors[i].red() * 255),
+                                 static_cast<unsigned char>(colors[i].green() * 255),
+                                 static_cast<unsigned char>(colors[i].blue() * 255));
       mesh1->addVertices(mesh->vertices(), mesh->normals(), colorsRGB);
-    } else { // probably a molecular orbital
+    } else {
       mesh1->setColor(m_color1);
       mesh1->addVertices(mesh->vertices(), mesh->normals());
-    }
-    mesh1->addTriangles(indices);
-    mesh1->setRenderPass(m_opacity == 255 ? Rendering::SolidPass
-                                          : Rendering::TranslucentPass);
+    }   
 
-    if (mol.meshCount() >= 2) { // it's a molecular orbital, two parts
+    // Add the triangles for the first mesh
+    for (size_t i = 0; i < triangles.size(); ++i) {
+      mesh1->addTriangle(triangles[i][0], triangles[i][1], triangles[i][2]);
+    }
+
+    mesh1->setRenderPass(m_opacity == 255 ? Rendering::SolidPass : Rendering::TranslucentPass);
+
+    // Handle the second mesh if present
+    if (mol.meshCount() >= 2) { 
       auto* mesh2 = new MeshGeometry;
       geometry->addDrawable(mesh2);
+
       mesh = mol.mesh(1);
-      if (mesh->numVertices() < indices.size()) {
-        indices.resize(mesh->numVertices());
-      } else if (mesh->numVertices() > indices.size()) {
-        indexGenerator.reset();
-        indices.resize(mesh->numVertices());
-        std::generate(indices.begin(), indices.end(), indexGenerator);
-      }
+
+      // Retrieve the second mesh’s triangles
+      Core::Array<Vector3f> triangles2 = mesh->triangles();
+
       mesh2->setColor(m_color2);
       mesh2->setOpacity(m_opacity);
       mesh2->addVertices(mesh->vertices(), mesh->normals());
-      mesh2->addTriangles(indices);
+
+      // Add the correct triangles for the second mesh
+      for (size_t i = 0; i < triangles2.size(); ++i) {
+        mesh2->addTriangle(triangles2[i][0], triangles2[i][1], triangles2[i][2]);
+      }
+
       mesh2->setRenderPass(m_opacity == 255 ? Rendering::SolidPass
                                             : Rendering::TranslucentPass);
     }
