@@ -3,7 +3,6 @@
   This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
-
 #ifndef AVOGADRO_QTPLUGINS_OBPROCESS_H
 #define AVOGADRO_QTPLUGINS_OBPROCESS_H
 
@@ -130,7 +129,7 @@ signals:
    *
    * If an error occurs, readFormats will be empty.
    */
-  void queryReadFormatsFinished(QMap<QString, QString> readFormats);
+  void queryReadFormatsFinished(QMultiMap<QString, QString> readFormats);
 
   /**
    * Triggered when the process started by queryWriteFormats() completes.
@@ -144,7 +143,7 @@ signals:
    *
    * If an error occurs, writeFormats will be empty.
    */
-  void queryWriteFormatsFinished(QMap<QString, QString> writeFormats);
+  void queryWriteFormatsFinished(QMultiMap<QString, QString> writeFormats);
 
 private slots:
   void queryReadFormatsPrepare();
@@ -253,7 +252,7 @@ signals:
    *
    * If an error occurs, forceFields will be empty.
    */
-  void queryForceFieldsFinished(const QMap<QString, QString>& forceFields);
+  void queryForceFieldsFinished(const QMultiMap<QString, QString>& forceFields);
 
 private slots:
   void queryForceFieldsPrepare();
@@ -271,7 +270,7 @@ public slots:
    * optimization finishes, optimizeGeometryFinished will be emitted with the
    * result of the optimization.
    *
-   * The optimization is started with, e.g. 
+   * The optimization is started with, e.g.
    * `obabel -icml -ocml --minimize <options>`
    *
    * The standard output is recorded and returned by optimizeGeometryFinished.
@@ -281,13 +280,17 @@ public slots:
    *
    * @return True if the process started successfully, false otherwise.
    */
-  bool optimizeGeometry(const QByteArray& cml, const QStringList& options, std::string format = "cml");
+  bool optimizeGeometry(const QByteArray& cml, const QStringList& options,
+                        std::string format = "cml");
+  bool generateConformers(const QByteArray& cml, const QStringList& options,
+                        std::string format = "cml");  
 signals:
   /**
    * Emitted with the standard output of the process when it finishes.
    * If an error occurs, the argument will not be valid CML.
    */
   void optimizeGeometryFinished(const QByteArray& cml);
+  void generateConformersFinished(const QByteArray& cml);
   /**
    * Emitted every 10 steps of the optimization to indicate the current
    * progress.
@@ -300,9 +303,14 @@ signals:
    */
   void optimizeGeometryStatusUpdate(int step, int maxSteps,
                                     double currentEnergy, double lastEnergy);
+
+  void conformerStatusUpdate(int step, int maxSteps, double currentEnergy,
+                             double lastEnergy);
 private slots:
   void optimizeGeometryPrepare();
   void optimizeGeometryReadLog();
+  void conformerPrepare();
+  void conformerReadLog();
 
   // end Force Fields doxygen group
   /**@}*/
@@ -331,7 +339,7 @@ public slots:
    */
   bool queryCharges();
 
-  signals:
+signals:
   /**
    * Triggered when the process started by queryCharges() completes.
    * @param charges The charge models supported by OpenBabel. Keys
@@ -340,7 +348,7 @@ public slots:
    *
    * If an error occurs, charges will be empty.
    */
-  void queryChargesFinished(const QMap<QString, QString>& charges);
+  void queryChargesFinished(const QMultiMap<QString, QString>& charges);
 
 private slots:
   void queryChargesPrepare();
@@ -359,11 +367,14 @@ public slots:
    * indicate return status along with the charges as text.
    *
    * The process is performed as:
-   * `obabel -i<inFormat> -onul --partialcharge <type> --print < input  > output`
+   * `obabel -i<inFormat> -onul --partialcharge <type> --print < input  >
+   * output`
    *
    * @return True if the process started successfully, false otherwise.
    */
-  bool calculateCharges(const QByteArray& input, const std::string& inFormat = "cml", const std::string& type = "mmff94");
+  bool calculateCharges(const QByteArray& input,
+                        const std::string& inFormat = "cml",
+                        const std::string& type = "mmff94");
 
 private slots:
   void chargesPrepareOutput();
@@ -423,6 +434,7 @@ executeObabel(options, this, SLOT(mySlot()));
 
   // Optimize geometry ivars:
   int m_optimizeGeometryMaxSteps;
+  unsigned m_maxConformers;
   QString m_optimizeGeometryLog;
 };
 
