@@ -408,7 +408,7 @@ void OpenMMInputDialog::generateClicked()
           tr("The input files cannot be written:\n\n%1").arg(errors.first());
         break;
       default: {
-        // If a fatal error occured, it will be last one in the list. Pop it off
+        // If a fatal error occurred, it will be last one in the list. Pop it off
         // and tell the user that it was the reason we had to stop.
         QString fatal = errors.last();
         QStringList tmp(errors);
@@ -956,7 +956,7 @@ QString OpenMMInputDialog::generateInputDeck()
   scriptStream << "nonbondedMethod="
                << "app." << getNonBondedType(m_nonBondedType) << ",";
   if (m_nonBondedCutoff > 0) {
-    scriptStream << " nonbondedCutoff=" << fixed << qSetRealNumberPrecision(4)
+    scriptStream << " nonbondedCutoff=" << Qt::fixed << qSetRealNumberPrecision(4)
                  << m_nonBondedCutoff << "*unit.nanometers,";
   }
   if (m_constraintType == None) {
@@ -967,7 +967,7 @@ QString OpenMMInputDialog::generateInputDeck()
   }
   scriptStream << ", rigidWater=" << getRigidWater(m_rigidWater);
   if (m_nonBondedType == Ewald || m_nonBondedType == PME) {
-    scriptStream << ", ewaldErrorTolerance=" << fixed
+    scriptStream << ", ewaldErrorTolerance=" << Qt::fixed
                  << qSetRealNumberPrecision(5) << m_ewaldTolerance;
   }
   scriptStream << ")\n";
