@@ -8,12 +8,8 @@
 
 #include <avogadro/qtgui/extensionplugin.h>
 
-// Forward declarations
-class QByteArray;
-class QStringList;
-
 namespace VTK {
-class VtkPlot;
+class ChartDialog;
 }
 
 namespace Avogadro {
@@ -64,7 +60,7 @@ private:
 
   QScopedPointer<PdfOptionsDialog> m_pdfOptionsDialog;
   QScopedPointer<QAction> m_displayDialogAction;
-  QScopedPointer<VTK::VtkPlot> m_plot;
+  QScopedPointer<VTK::ChartDialog> m_chartDialog;
 };
 
 inline QString PlotPdf::description() const
