@@ -1,17 +1,6 @@
 /******************************************************************************
-
  This source file is part of the Avogadro project.
-
- Copyright 2013 Kitware, Inc.
-
- This source code is released under the New BSD License, (the "License").
-
- Unless required by applicable law or agreed to in writing, software
- distributed under the License is distributed on an "AS IS" BASIS,
- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- See the License for the specific language governing permissions and
- limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
  ******************************************************************************/
 
 #ifndef AVOGADRO_QTPLUGINS_PLUGINFACTORY_H
@@ -20,8 +9,7 @@
 #include <QtCore/QObject>
 #include <QtCore/QString>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 /**
  * @class PluginFactory pluginfactory.h <avogadro/qtplugins/pluginfactory.h>
@@ -38,7 +26,6 @@ public:
   virtual QString description() const = 0;
 };
 
-} /* namespace QtPlugins */
 } /* namespace Avogadro */
 
 #endif /* AVOGADRO_QTPLUGINS_PLUGINFACTORY_H */
