@@ -14,7 +14,6 @@
 
 #include <QDebug>
 
-using namespace std;
 using namespace Avogadro;
 using namespace Avogadro::Rendering;
 
@@ -25,10 +24,6 @@ QTAIMEngine::QTAIMEngine(QObject* aParent)
 {
 }
 
-QTAIMEngine::~QTAIMEngine()
-{
-}
-
 void QTAIMEngine::process(const QtGui::Molecule& molecule,
                           Rendering::GroupNode& node)
 {
