@@ -24,7 +24,7 @@ namespace Avogadro::QtPlugins {
 Spectra::Spectra(QObject* p)
   : ExtensionPlugin(p), m_molecule(nullptr), m_dialog(nullptr)
 {
-  QAction* action = new QAction(this);
+  auto* action = new QAction(this);
   action->setEnabled(false);
   action->setText(tr("Plot Spectra…"));
   action->setProperty("menu priority", -900);
@@ -32,8 +32,6 @@ Spectra::Spectra(QObject* p)
   m_actions.push_back(action);
 }
 
-Spectra::~Spectra() {}
-
 QList<QAction*> Spectra::actions() const
 {
   return m_actions;
@@ -108,6 +106,10 @@ void Spectra::openDialog()
   }
 
   gatherSpectra();
+  // update the elements
+  auto elements = m_molecule->atomicNumbers();
+  std::vector<unsigned char> atomicNumbers(elements.begin(), elements.end());
+  m_dialog->setElements(atomicNumbers);
   m_dialog->show();
 }
 
