@@ -45,9 +45,17 @@ public:
   void readSettings();
 
   void setSpectra(const std::map<std::string, MatrixX>& spectra);
+  void setElements(const std::vector<unsigned char>& elements)
+  {
+    m_elements = elements;
+    updateElementCombo();
+  }
 
   VTK::ChartWidget* chartWidget();
 
+  void disconnectOptions();
+  void connectOptions();
+
 private slots:
   void changeBackgroundColor();
   void changeForegroundColor();
@@ -57,14 +65,19 @@ private slots:
   void changeLineWidth();
   void changeSpectra();
 
+  void updateElementCombo();
   void updatePlot();
 
   void toggleOptions();
 
 private:
   std::map<std::string, MatrixX> m_spectra;
+  std::vector<unsigned char> m_elements; // for NMR
+  // current spectra data
+  std::vector<double> m_transitions;
+  std::vector<double> m_intensities;
 
-  QString m_currentSpectra;
+  QString m_currentSpectraType;
   Ui::SpectraDialog* m_ui;
 };
 
