@@ -6,9 +6,6 @@
 #include "surfaces.h"
 #include "surfacedialog.h"
 
-#include "gaussiansetconcurrent.h"
-#include "slatersetconcurrent.h"
-
 // Header only, but duplicate symbols if included globally...
 namespace {
 #include <gif.h>
@@ -25,9 +22,11 @@ namespace {
 #include <avogadro/core/cube.h>
 #include <avogadro/core/mesh.h>
 #include <avogadro/core/neighborperceiver.h>
+#include <avogadro/qtgui/gaussiansetconcurrent.h>
 #include <avogadro/qtgui/meshgenerator.h>
 #include <avogadro/qtgui/molecule.h>
 #include <avogadro/qtgui/rwlayermanager.h>
+#include <avogadro/qtgui/slatersetconcurrent.h>
 #include <avogadro/qtopengl/activeobjects.h>
 #include <avogadro/qtopengl/glwidget.h>
 
@@ -68,7 +67,9 @@ using Core::Array;
 using Core::Cube;
 using Core::GaussianSet;
 using Core::NeighborPerceiver;
+using QtGui::GaussianSetConcurrent;
 using QtGui::Molecule;
+using QtGui::SlaterSetConcurrent;
 
 class Surfaces::PIMPL
 {
@@ -559,7 +560,6 @@ void Surfaces::calculateQM(Type type, int index, bool beta, float isoValue,
   // TODO: Check to see if this cube or surface has already been computed
   if (!m_progressDialog) {
     m_progressDialog = new QProgressDialog(qobject_cast<QWidget*>(parent()));
-    m_progressDialog->setCancelButtonText(nullptr);
     m_progressDialog->setWindowModality(Qt::NonModal);
     connectSlots = true;
   }
@@ -628,6 +628,8 @@ void Surfaces::calculateQM(Type type, int index, bool beta, float isoValue,
               SIGNAL(progressRangeChanged(int, int)), m_progressDialog,
               SLOT(setRange(int, int)));
       connect(m_gaussianConcurrent, SIGNAL(finished()), SLOT(displayMesh()));
+      connect(m_progressDialog, SIGNAL(canceled()),
+              &m_gaussianConcurrent->watcher(), SLOT(cancel()));
     }
   } else {
     // slaters
@@ -642,6 +644,8 @@ void Surfaces::calculateQM(Type type, int index, bool beta, float isoValue,
     connect(&m_slaterConcurrent->watcher(),
             SIGNAL(progressRangeChanged(int, int)), m_progressDialog,
             SLOT(setRange(int, int)));
+    connect(m_progressDialog, SIGNAL(canceled()),
+            &m_slaterConcurrent->watcher(), SLOT(cancel()));
     connect(m_slaterConcurrent, SIGNAL(finished()), SLOT(displayMesh()));
   }
 }
