@@ -19,8 +19,7 @@
 
 using namespace Avogadro::QtPlugins::SymmetryUtil;
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 OperationsTableModel::OperationsTableModel(QObject* parent)
   : QAbstractTableModel(parent)
@@ -89,4 +88,3 @@ QVariant OperationsTableModel::data(const QModelIndex& index, int role) const
   }
 }
 }
-}
