@@ -121,6 +121,19 @@ public:
    */
   void calculatePerspective(float fieldOfView, float zNear, float zFar);
 
+  /**
+   * Calculate the perspective projection matrix using frustum planes
+   * coordinates.
+   * @param left left vertical clipping plane.
+   * @param right right vertical clipping plane.
+   * @param bottom bottom horizontal clipping plane.
+   * @param top top horizontal clipping plane.
+   * @param zNear distance to the near clipping plane.
+   * @param zFar distance to the far clipping plane.
+   */
+  void calculatePerspective(float left, float right, float bottom, float top,
+                            float zNear, float zFar);
+
   /**
    * Calculate the orthographic projection matrix.
    * @param left left vertical clipping plane.
