@@ -28,8 +28,15 @@ using Core::Array;
 
 const size_t CurveGeometry::SKIPPED = 1;
 
-CurveGeometry::CurveGeometry() : m_dirty(true), m_canBeFlat(true) {}
-CurveGeometry::CurveGeometry(bool flat) : m_dirty(true), m_canBeFlat(flat) {}
+CurveGeometry::CurveGeometry() : m_dirty(true), m_canBeFlat(true)
+{
+  setRenderPass(SolidPass);
+}
+
+CurveGeometry::CurveGeometry(bool flat) : m_dirty(true), m_canBeFlat(flat)
+{
+  setRenderPass(SolidPass);
+}
 
 CurveGeometry::~CurveGeometry()
 {
