@@ -14,6 +14,7 @@
 #include "scene.h"
 #include "shader.h"
 #include "shaderprogram.h"
+#include "solidpipeline.h"
 
 #include <avogadro/core/array.h>
 
@@ -44,6 +45,9 @@ public:
   /** Resize the context in response to window management events. */
   void resize(int width, int height);
 
+  /** Set the ratio of physical to logical pixels. */
+  void setPixelRatio(float ratio);
+
   /** Take care of rendering the scene, requires that the context is current. */
   void render();
 
@@ -64,6 +68,11 @@ public:
    */
   Identifier hit(int x, int y) const;
 
+  /** Return the depth of provided ray - geometry hit test.
+   */
+  float hit(const Vector3f& rayOrigin, const Vector3f& rayEnd,
+            const Vector3f& rayDirection) const;
+
   /** Return the primitives in the rectangular area provided. */
   Core::Array<Identifier> hits(int x1, int y1, int x2, int y2) const;
 
@@ -87,6 +96,10 @@ public:
   const Scene& scene() const { return m_scene; }
   Scene& scene() { return m_scene; }
 
+  /** Get the solid pipeline for this renderer. */
+  const SolidPipeline& solidPipeline() const { return m_solidPipeline; }
+  SolidPipeline& solidPipeline() { return m_solidPipeline; }
+
   /**
    * Get/set the text rendering strategy for this object. The renderer takes
    * ownership of the strategy object. @{
@@ -96,6 +109,16 @@ public:
   void setTextRenderStrategy(TextRenderStrategy* tren);
   /** @} */
 
+  std::array<float, 6> m_perspectiveFrustum;  // L, R, B, T, N, F (planes order)
+  std::array<float, 6> m_orthographicFrustum; // L, R, B, T, N, F (planes order)
+#ifdef _3DCONNEXION
+  bool m_drawIcon;
+  void* m_iconData;
+  uint32_t m_iconWidth;
+  uint32_t m_iconHeight;
+  Eigen::Vector3f m_iconPosition;
+#endif
+
 private:
   /**
    * Apply the projection matrix.
@@ -127,6 +150,7 @@ private:
   Camera m_overlayCamera;
   Scene m_scene;
   TextRenderStrategy* m_textRenderStrategy;
+  SolidPipeline m_solidPipeline;
 
   Vector3f m_center;
   float m_radius;
