@@ -1,8 +1,6 @@
 #!/usr/bin/env bash
 set -ev
 
-pip install cibuildwheel==2.0.0
-
 if [[ $RUNNER_OS == "Windows" ]]; then
     git clone --recursive -b 3.4.0 --depth 1 https://gitlab.com/libeigen/eigen /c/eigen
     cd /c/eigen
@@ -13,5 +11,5 @@ if [[ $RUNNER_OS == "Windows" ]]; then
 elif [[ $RUNNER_OS == "macOS" ]]; then
     brew install eigen
 else
-    sudo apt install libeigen3-dev
+    ls -la
 fi
